% Example 5 in "Wavelet density estimation for stratified size-biased sample"
% by Pepa Ramirez & Brani Vidakovic.

% In this example, under the same density and biased functions that Example
% 2, we consider the problem of estimating the second and third biasing
% functions ( g2(y)=y^3/2 -- g3(y)= y^2 ), asuming the first ( g1(y)=y ) is known. 

%
%  The program calls to:
%           1) Phijk.m -- Daubechies-Lagarias Algorithm. 
%           2) dwtr.m and idwtr.m -- forward and inverse wavelet transform.
%           3) loc_lin.m and kernel.m -- local linear smoother with a
%           Gaussian kernel.
%           4) FWT_CDJV.m, IWT_CDJV.m -- boundary-corrected forward and
%           inverse wavelet transform, from the WaveLab package (Donoho et al.)
%           available at http://www-stat.stanford.edu/~wavelab/           
%--------------------------------------------------------------------------


close all
clear all
% We assume that both fY1 and g1 are known. Let us simulate the biased
% sample from the first stratum:
n1 = 1000; y1 = betarnd(3,2,n1,1);
muhat1 = n1./sum(1./y1);

filter =[-0.07576571478934,  -0.02963552764595,   0.49761866763246,   0.80373875180522,...
   0.29785779560554,  -0.09921954357694,  -0.01260396726226,   0.03222310060407];

J=7;
cs =[];
for k = 0:(2^J-1)
    cJk = 0;
for i = 1:n1
    cJk = cJk + Phijk(y1(i), J, k, filter, 20)/y1(i); 
end
cJk = muhat1/n1 * cJk;
cs =[cs cJk];
end
cs = 2^(J/2) * cs;
a = linspace(0,1, length(cs));
wf = MakeONFilterExt('Coiflet',1);
csw = FWT_CDJV(cs, 2,3);
nn = length(csw);
nn2 = nn/2;
finest = csw(nn2+1:nn);
sigma = 1.4826*median(abs(finest-median(finest)));
lambda = sqrt( 2 * log(nn)) * sigma;
cswt = csw .* ( abs(csw) > lambda); %hard threshold
linear_est = IWT_CDJV(cswt, 2, 3);  % This is the linear estimate of fX,

%-------------------------------------------
% From the linear estimate of fX, we compute the second and third biasing
% functions. 
a1 = a(2:(length(a)-3)); %In log-scales,
log_gmu2_est = -log(beta(7/2,2))+5/2*log(a1)+log(1-a1)-log(linear_est(2:125));
figure(1)
plot(a1,log_gmu2_est,'k--');
hold on
log_gmu2_true = -log(beta(7/2,2))+(5/2)*log(a1) + log(beta(2,2))-log(a1);
plot(a1,log_gmu2_true)
log_gmu3_est= -log(beta(4,2))+3*log(a1)+log(1-a1)-log(linear_est(2:125));
figure(2)
plot(a1,log_gmu3_est,'k--');
hold on
log_gmu3_true = -log(beta(4,2))+3*log(a1)+log(beta(2,2))-log(a1);
plot(a1,log_gmu3_true)

